@@ -4,7 +4,7 @@ import pkgutil
 import sys
 import importlib
 from types import ModuleType
-from typing import Any, Optional, Sequence
+from typing import Any, Optional
 import click
 from click_help_colors import HelpColorsGroup  # type: ignore
 from click_didyoumean import DYMGroup  # type: ignore
@@ -24,27 +24,20 @@ class AdvancedGroup(ClickAliasedGroup, DYMGroup, HelpColorsGroup):  # type: igno
     def __init__(self, *args: Any, aliases: Optional[str] = None, **kwargs: Any):
         kwargs['help_headers_color'] = 'yellow'
         kwargs['help_options_color'] = 'green'
-        # super(AdvancedGroup, self).__init__(*args, aliases=aliases, **kwargs)
         super().__init__(*args, **kwargs)
-        # print(f"{self} : {args} | {kwargs}")
         self.aliases = aliases if aliases is not None else []
 
         @click.command('help')
-        @click.argument('command', nargs=-1)
         @click.pass_context
-        def _help(ctx: Optional[click.Context], command: Sequence[click.Command]) -> None:
+        def _help(ctx: Optional[click.Context]) -> None:
             '''Print help'''
             # we accept many commands, but only show help of the first one
             if not ctx:
                 raise RuntimeError('no click context available')
-            if command:
-                first_command = command[0]
-                command_obj = self.get_command(ctx, first_command)
-                print(command_obj.get_help(ctx))
-            else:
-                if not ctx.parent:
-                    raise RuntimeError('no click context parent available')
-                print(ctx.parent.get_help())
+            if not ctx.parent:
+                raise RuntimeError('no click context parent available')
+            click.echo(ctx.parent.get_help(), color=ctx.color)
+            ctx.exit()
 
         self.add_command(_help, 'help')
 
